Wired Text To Speech
====================

gTTS based Wired story reader.


Install
-------

Just `pip install` as follow:

.. code:: bash

    $ pip install wired-tts


Usage
-----

Just call it with your article url as follow:

.. code:: bash

    $ wired-tts https://www.wired.com/story/tezos-blockchain-love-story-horror-story/


License
-------

MIT License
